package com.javacodegeeks.nio_ftp_example;

import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.channels.FileChannel;
import java.nio.file.Paths;
import java.nio.file.StandardOpenOption;
import java.util.Objects;

final class FileWriter {

    private final FileChannel target;

    FileWriter(final String path) throws IOException {
        this.target = FileChannel.open(Paths.get(path), StandardOpenOption.WRITE, StandardOpenOption.CREATE);
    }

    void write(final ByteBuffer buffer) throws IOException {
        this.target.write(buffer);

        while (buffer.hasRemaining()) {
            buffer.compact();
            this.target.write(buffer);
        }
    }

    void close() throws IOException {
        Objects.requireNonNull(this.target).close();
    }
}
