package com.javacodegeeks.nio_ftp_example;

import java.io.IOException;
import java.net.URL;
import java.nio.ByteBuffer;
import java.util.Objects;

import org.apache.commons.lang3.StringUtils;

public final class NIOftp {

    private static final int FTP_BUFFER_CAPACITY = 2048;

    private NIOftp() {
        throw new IllegalStateException(Constants.INSTANTIATION_NOT_ALLOWED);
    }

    public static void ftp(final URL from, final String target) throws IOException {
        if (Objects.isNull(from)) {
            throw new IllegalArgumentException("URL required for ftp source");
        }

        if (StringUtils.isBlank(target)) {
            throw new IllegalArgumentException("target required");
        }

        final FileReader reader = createReader(from);
        final FileWriter writer = createWriter(target);

        try {
            System.out.printf("Starting ftp from %s\n", from.toString());
            
            ByteBuffer buffer = ByteBuffer.allocate(FTP_BUFFER_CAPACITY);
            while (reader.read(buffer) >= 0) {
                writer.write((ByteBuffer) buffer.flip());

                buffer.clear();
            }
        } finally {
            System.out.println("Completed transfer");
            
            reader.close();
            writer.close();
        }
    }

    private static FileReader createReader(final URL from) throws IOException {
        assert !Objects.isNull(from);

        return new FileReader(from);
    }

    private static FileWriter createWriter(final String target) throws IOException {
        assert StringUtils.isNotBlank(target);

        return new FileWriter(target);
    }
}
