package com.javacodegeeks.nio_ftp_example.runner;

import java.net.MalformedURLException;
import java.util.Objects;
import java.util.Optional;

import org.apache.commons.cli.CommandLine;
import org.apache.commons.cli.CommandLineParser;
import org.apache.commons.cli.DefaultParser;
import org.apache.commons.cli.HelpFormatter;
import org.apache.commons.cli.Options;
import org.apache.commons.cli.ParseException;

import com.javacodegeeks.nio_ftp_example.Constants;

final class CLIConfigurator {

    private static final String FTP_PROTOCOL_PREFIX = "ftp";
    
    static final String URL = "u";
    static final String TARGET = "t";

    private static final Options CLI_OPTIONS = new Options();
    static {
        CLI_OPTIONS.addOption(String.valueOf(URL), true, "The url to transfer file from eg: ftp://server/file");
        CLI_OPTIONS.addOption(String.valueOf(TARGET), true, "The destination to which the file should be saved");
    }

    private CLIConfigurator() {
        throw new IllegalStateException(Constants.INSTANTIATION_NOT_ALLOWED);
    }

    static Optional<CLIConfig> configure(final String... args) {
        assert !Objects.isNull(args);

        Optional<CLIConfig> result = Optional.empty();

        try {
            final CommandLineParser parser = new DefaultParser();
            final CommandLine cmd = parser.parse(CLI_OPTIONS, args);

            if (cmd.hasOption(URL) && cmd.getOptionValue(URL).startsWith(FTP_PROTOCOL_PREFIX) && cmd.hasOption(TARGET)) {
                result = Optional.of(new CLIConfig(cmd));
            } else {
                printUsage();
            }
        } catch (MalformedURLException | ParseException e) {
            e.printStackTrace();
            
            printUsage();
        }

        return result;
    }

    private static void printUsage() {
        final HelpFormatter help = new HelpFormatter();
        help.printHelp("Running heartbeat", CLI_OPTIONS);
    }
}
